@@ -1,9 +1,9 @@
 /*
- *  $Id: formbox.c,v 1.108 2024/04/08 23:28:10 tom Exp $
+ *  $Id: formbox.c,v 1.111 2026/01/01 13:56:37 tom Exp $
  *
  *  formbox.c -- implements the form (i.e., some pairs label/editbox)
  *
- *  Copyright 2003-2022,2024	Thomas E. Dickey
+ *  Copyright 2003-2025,2026	Thomas E. Dickey
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License, version 2.1
@@ -180,7 +180,7 @@ form_limit(DIALOG_FORMITEM item[])
 {
     int n;
     int limit = 0;
-    for (n = 0; item[n].name != 0; ++n) {
+    for (n = 0; item[n].name != NULL; ++n) {
 	if (limit < item[n].name_y)
 	    limit = item[n].name_y;
 	if (limit < item[n].text_y)
@@ -311,7 +311,7 @@ scroll_next(WINDOW *win, DIALOG_FORMITEM item[], int stepsize, int *choice, int
     if (result) {
 	int n;
 
-	for (n = 0; item[n].name != 0; ++n) {
+	for (n = 0; item[n].name != NULL; ++n) {
 	    if (item[n].text_flen > 0) {
 		int new_row = MIN(item[n].text_y, item[n].name_y);
 		if (abs(new_row - target) < abs(old_row - target)) {
@@ -384,14 +384,15 @@ make_FORM_ELTs(DIALOG_FORMITEM * item,
 	 * We do not know the actual length of .text, so we allocate it here
 	 * to ensure it is big enough.
 	 */
+#define InputLimit(ilen) dlg_max_input(MAX(ilen + 1, MAX_LEN))
 	if (item[i].text_flen > 0) {
-	    int max_len = dlg_max_input(MAX(item[i].text_ilen + 1, MAX_LEN));
+	    int max_len = InputLimit(item[i].text_ilen);
 	    char *old_text = item[i].text;
 
 	    item[i].text = dlg_malloc(char, (size_t) max_len + 1);
 	    assert_ptr(item[i].text, "make_FORM_ELTs");
 
-	    sprintf(item[i].text, "%.*s", item[i].text_ilen, old_text);
+	    sprintf(item[i].text, "%.*s", max_len, old_text);
 
 	    if (item[i].text_free) {
 		free(old_text);
@@ -409,9 +410,9 @@ dlg_default_formitem(DIALOG_FORMITEM * items)
 {
     int result = 0;
 
-    if (dialog_vars.default_item != 0) {
+    if (dialog_vars.default_item != NULL) {
 	int count = 0;
-	while (items->name != 0) {
+	while (items->name != NULL) {
 	    if (!strcmp(dialog_vars.default_item, items->name)) {
 		result = count;
 		break;
@@ -869,7 +870,7 @@ dlg_form(const char *title,
 	if (state == sTEXT) {	/* Input box selected */
 	    if (!is_readonly(current)) {
 		int save = dialog_vars.max_input;
-		dialog_vars.max_input = current->text_ilen;
+		dialog_vars.max_input = InputLimit(current->text_ilen);
 		edit = dlg_edit_string(current->text, &chr_offset, key,
 				       fkey, first);
 		dialog_vars.max_input = save;
@@ -903,7 +904,7 @@ void
 dlg_free_formitems(DIALOG_FORMITEM * items)
 {
     int n;
-    for (n = 0; items[n].name != 0; ++n) {
+    for (n = 0; items[n].name != NULL; ++n) {
 	if (items[n].name_free)
 	    free(items[n].name);
 	if (items[n].text_free)
